Class: Google::Cloud::Scheduler::V1::AppEngineHttpTarget
- Inherits:
-
Object
- Object
- Google::Cloud::Scheduler::V1::AppEngineHttpTarget
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/scheduler/v1/target.rb
Overview
App Engine target. The job will be pushed to a job handler by means of an HTTP request via an http_method such as HTTP POST, HTTP GET, etc. The job is acknowledged by means of an HTTP response code in the range [200 - 299]. Error 503 is considered an App Engine system error instead of an application error. Requests returning error 503 will be retried regardless of retry configuration and not counted against retry counts. Any other response code, or a failure to receive a response before the deadline, constitutes a failed attempt.
Defined Under Namespace
Classes: HeadersEntry
Instance Attribute Summary collapse
-
#app_engine_routing ⇒ ::Google::Cloud::Scheduler::V1::AppEngineRouting
App Engine Routing setting for the job.
-
#body ⇒ ::String
Body.
-
#headers ⇒ ::Google::Protobuf::Map{::String => ::String}
HTTP request headers.
-
#http_method ⇒ ::Google::Cloud::Scheduler::V1::HttpMethod
The HTTP method to use for the request.
-
#relative_uri ⇒ ::String
The relative URI.
Instance Attribute Details
#app_engine_routing ⇒ ::Google::Cloud::Scheduler::V1::AppEngineRouting
Returns App Engine Routing setting for the job.
191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/cloud/scheduler/v1/target.rb', line 191 class AppEngineHttpTarget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class HeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#body ⇒ ::String
Returns Body.
HTTP request body. A request body is allowed only if the HTTP method is POST or PUT. It will result in invalid argument error to set a body on a job with an incompatible HttpMethod.
191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/cloud/scheduler/v1/target.rb', line 191 class AppEngineHttpTarget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class HeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#headers ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns HTTP request headers.
This map contains the header field names and values. Headers can be set when the job is created.
Cloud Scheduler sets some headers to default values:
User-Agent: By default, this header is"AppEngine-Google; (+http://code.google.com/appengine)". This header can be modified, but Cloud Scheduler will append"AppEngine-Google; (+http://code.google.com/appengine)"to the modifiedUser-Agent.X-CloudScheduler: This header will be set to true.X-CloudScheduler-JobName: This header will contain the job name.X-CloudScheduler-ScheduleTime: For Cloud Scheduler jobs specified in the unix-cron format, this header will contain the job schedule as an offset of UTC parsed according to RFC3339.
If the job has a body and the following headers are not set by the user, Cloud Scheduler sets default values:
Content-Type: This will be set to"application/octet-stream". You can override this default by explicitly settingContent-Typeto a particular media type when creating the job. For example, you can setContent-Typeto"application/json".
The headers below are output only. They cannot be set or overridden:
Content-Length: This is computed by Cloud Scheduler.X-Google-*: For Google internal use only.X-AppEngine-*: For Google internal use only.
In addition, some App Engine headers, which contain job-specific information, are also be sent to the job handler.
191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/cloud/scheduler/v1/target.rb', line 191 class AppEngineHttpTarget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class HeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#http_method ⇒ ::Google::Cloud::Scheduler::V1::HttpMethod
Returns The HTTP method to use for the request. PATCH and OPTIONS are not permitted.
191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/cloud/scheduler/v1/target.rb', line 191 class AppEngineHttpTarget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class HeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#relative_uri ⇒ ::String
Returns The relative URI.
The relative URL must begin with "/" and must be a valid HTTP relative URL.
It can contain a path, query string arguments, and # fragments.
If the relative URL is empty, then the root path "/" will be used.
No spaces are allowed, and the maximum length allowed is 2083 characters.
191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/cloud/scheduler/v1/target.rb', line 191 class AppEngineHttpTarget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class HeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |